@@ -40,11 +40,11 @@ def main(command, poll_interval, shell):
         os.kill(proc.pid, signal.SIGINT)
 
     # Get means and maxes
-    for name in ['rss_mem_kb', 'vms_mem_kb', 'num_threads', 'num_fds']:
-        output['avg_%s' % name] = mean(records[name])
-        output['max_%s' % name] = max(records[name])
+    for name, values in records.items():
+        output['avg_%s' % name] = mean(values)
+        output['max_%s' % name] = max(values)
 
-    # Calculate some extra fielsd
+    # Calculate some extra fields
     output['exit_status'] = proc.poll()
     end_time = time.time()  # waiting till last second
     output['num_polls'] = num_polls
